import { useQuery } from "@tanstack/react-query";
import { Link } from "wouter";
import { Skeleton } from "@/components/ui/skeleton";
import { Button } from "@/components/ui/button";
import { ChevronRight, Star, StarHalf } from "@/lib/icons";
import { type Product } from "@/lib/types";
import { useCart } from "@/hooks/use-cart";
import { useToast } from "@/hooks/use-toast";

const ProductCard = ({ product }: { product: Product }) => {
  const { addItem } = useCart();
  const { toast } = useToast();
  
  // Generate stars based on product rating
  const generateStars = (rating: number) => {
    const stars = [];
    const fullStars = Math.floor(rating);
    const hasHalfStar = rating - fullStars >= 0.5;
    
    for (let i = 0; i < fullStars; i++) {
      stars.push(<Star key={`star-${i}`} className="text-yellow-400" />);
    }
    
    if (hasHalfStar) {
      stars.push(<StarHalf key="half-star" className="text-yellow-400" />);
    }
    
    return stars;
  };

  const handleAddToCart = () => {
    addItem(product);
    toast({
      title: "Ajouté au panier",
      description: `${product.title} a été ajouté à votre panier.`,
      duration: 3000,
    });
  };

  return (
    <div className="bg-white rounded-xl shadow-md overflow-hidden hover:shadow-lg transition-shadow">
      <div className="relative">
        <Link href={`/products/${product.slug}`}>
          <img 
            src={product.imageUrl} 
            alt={product.title} 
            className="w-full h-56 object-cover" 
          />
        </Link>
        {product.isBestseller && (
          <div className="absolute top-3 right-3 bg-[#ff9633] text-white text-sm font-medium py-1 px-2 rounded shadow-sm">
            Bestseller
          </div>
        )}
        {product.isNew && !product.isBestseller && (
          <div className="absolute top-3 right-3 bg-[#ff9633] text-white text-sm font-medium py-1 px-2 rounded shadow-sm">
            Nouveauté
          </div>
        )}
      </div>
      <div className="p-5">
        <Link href={`/products/${product.slug}`}>
          <h3 className="text-lg font-bold font-montserrat text-gray-900 mb-2 hover:text-primary-700 transition-colors">
            {product.title}
          </h3>
        </Link>
        <p className="text-gray-600 text-sm mb-3">{product.description}</p>
        <div className="flex justify-between items-center mb-4">
          <span className="text-[#f97316] font-bold">{product.price.toFixed(2)} €</span>
          <div className="flex items-center">
            {generateStars(product.rating)}
            <span className="text-sm text-gray-500 ml-1">({product.reviewCount})</span>
          </div>
        </div>
        <div className="grid grid-cols-2 gap-2">
          <Button 
            className="bg-[#ff9633] hover:bg-[#f97316] text-white font-medium shadow-sm"
            onClick={handleAddToCart}
          >
            Ajouter au panier
          </Button>
          <Link href={`/checkout?productId=${product.id}`}>
            <Button className="w-full bg-primary-700 hover:bg-primary-800 text-white font-medium shadow-sm">
              Acheter
            </Button>
          </Link>
        </div>
      </div>
    </div>
  );
};

const ProductSkeleton = () => (
  <div className="bg-white rounded-xl shadow-md overflow-hidden">
    <Skeleton className="h-56 w-full" />
    <div className="p-5">
      <Skeleton className="h-6 w-3/4 mb-2" />
      <Skeleton className="h-4 w-full mb-3" />
      <div className="flex justify-between items-center mb-4">
        <Skeleton className="h-5 w-16" />
        <Skeleton className="h-4 w-24" />
      </div>
      <Skeleton className="h-10 w-full" />
    </div>
  </div>
);

const BestsellerSection = () => {
  const { data: bestsellers, isLoading } = useQuery<Product[]>({
    queryKey: ['/api/products/bestsellers/list'],
  });

  return (
    <section id="bestsellers" className="py-16 bg-white">
      <div className="container mx-auto px-4 sm:px-6 lg:px-8">
        <div className="flex justify-between items-end mb-12">
          <div>
            <h2 className="text-3xl font-bold font-montserrat text-gray-900 mb-2">Meilleures Ventes</h2>
            <p className="text-lg text-gray-600">Les eBooks les plus populaires de notre collection</p>
          </div>
          <a 
            href="#bestsellers"
            className="hidden md:flex items-center text-primary-700 hover:text-primary-800 font-medium"
            onClick={(e) => {
              e.preventDefault();
              document.getElementById('bestsellers')?.scrollIntoView({ behavior: 'smooth', block: 'start' });
            }}
          >
            Voir tous <ChevronRight className="ml-1 h-5 w-5" />
          </a>
        </div>
        
        <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4 gap-8">
          {isLoading ? (
            <>
              <ProductSkeleton />
              <ProductSkeleton />
              <ProductSkeleton />
              <ProductSkeleton />
            </>
          ) : (
            bestsellers?.map((product) => (
              <ProductCard key={product.id} product={product} />
            ))
          )}
        </div>
        
        <div className="mt-8 text-center md:hidden">
          <Link href="/categories" className="inline-flex items-center text-primary-700 hover:text-primary-800 font-medium">
            Voir tous les bestsellers <ChevronRight className="ml-1 h-5 w-5" />
          </Link>
        </div>
      </div>
    </section>
  );
};

export default BestsellerSection;
