import { useQuery } from "@tanstack/react-query";
import { Link } from "wouter";
import { Skeleton } from "@/components/ui/skeleton";
import { ChevronRight } from "@/lib/icons";
import { type Category } from "@/lib/types";

const CategoryCard = ({ category }: { category: Category }) => {
  return (
    <div className="bg-white rounded-xl shadow-md overflow-hidden transition-transform hover:scale-105">
      <div className={`h-40 ${category.colorClass} relative`}>
        <img 
          src={category.imageUrl} 
          alt={category.name} 
          className="w-full h-full object-cover mix-blend-overlay" 
        />
        <div className="absolute inset-0 bg-gradient-to-t from-black to-transparent opacity-70"></div>
        <h3 className="absolute bottom-4 left-4 text-white text-xl font-bold font-montserrat drop-shadow-md">{category.name}</h3>
      </div>
      <div className="p-5">
        <p className="text-gray-600 mb-4">{category.description}</p>
        <Link 
          href={`/categories/${category.slug}`} 
          className="text-primary-700 font-medium hover:text-primary-800 flex items-center"
        >
          Explorer <ChevronRight className="ml-1 h-5 w-5" />
        </Link>
      </div>
    </div>
  );
};

const CategorySkeleton = () => (
  <div className="bg-white rounded-xl shadow-md overflow-hidden">
    <Skeleton className="h-40 w-full" />
    <div className="p-5">
      <Skeleton className="h-4 w-3/4 mb-4" />
      <Skeleton className="h-4 w-full mb-2" />
      <Skeleton className="h-4 w-1/2" />
    </div>
  </div>
);

const CategorySection = () => {
  const { data: categories, isLoading } = useQuery<Category[]>({
    queryKey: ['/api/categories'],
  });

  return (
    <section id="categories" className="py-16 bg-gray-50">
      <div className="container mx-auto px-4 sm:px-6 lg:px-8">
        <div className="text-center mb-12">
          <h2 className="text-3xl font-bold font-montserrat text-gray-900 mb-4">Catégories d'eBooks</h2>
          <p className="text-lg text-gray-600 max-w-2xl mx-auto">
            Explorez notre vaste collection d'eBooks dans différentes catégories
          </p>
        </div>
        
        <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-4 gap-8">
          {isLoading ? (
            <>
              <CategorySkeleton />
              <CategorySkeleton />
              <CategorySkeleton />
              <CategorySkeleton />
            </>
          ) : (
            categories?.map((category) => (
              <CategoryCard key={category.id} category={category} />
            ))
          )}
        </div>
      </div>
    </section>
  );
};

export default CategorySection;
