import { useState } from "react";
import { useMutation } from "@tanstack/react-query";
import { useForm } from "react-hook-form";
import { zodResolver } from "@hookform/resolvers/zod";
import { z } from "zod";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import {
  Form,
  FormControl,
  FormField,
  FormItem,
  FormMessage,
} from "@/components/ui/form";
import { useToast } from "@/hooks/use-toast";
import { apiRequest } from "@/lib/queryClient";

const formSchema = z.object({
  email: z.string().email("Veuillez entrer une adresse email valide")
});

type FormValues = z.infer<typeof formSchema>;

const Newsletter = () => {
  const { toast } = useToast();
  const [isSuccess, setIsSuccess] = useState(false);

  const form = useForm<FormValues>({
    resolver: zodResolver(formSchema),
    defaultValues: {
      email: ""
    }
  });

  const mutation = useMutation({
    mutationFn: async (values: FormValues) => {
      const response = await apiRequest("POST", "/api/newsletter", values);
      return response.json();
    },
    onSuccess: () => {
      toast({
        title: "Inscription réussie",
        description: "Vous êtes maintenant inscrit à notre newsletter.",
      });
      setIsSuccess(true);
      form.reset();
    },
    onError: (error) => {
      toast({
        title: "Erreur",
        description: "Une erreur est survenue lors de l'inscription. Veuillez réessayer.",
        variant: "destructive",
      });
    }
  });

  const onSubmit = (values: FormValues) => {
    mutation.mutate(values);
  };

  return (
    <section className="py-16 bg-primary-800 text-white">
      <div className="container mx-auto px-4 sm:px-6 lg:px-8">
        <div className="max-w-2xl mx-auto text-center">
          <h2 className="text-3xl font-bold font-montserrat mb-4 text-white drop-shadow-sm">Restez informés</h2>
          <p className="text-lg text-white mb-8 drop-shadow-sm">
            Inscrivez-vous à notre newsletter pour recevoir les dernières nouveautés et offres exclusives
          </p>
          
          {isSuccess ? (
            <div className="bg-white/20 rounded-lg p-6 backdrop-blur-sm shadow-xl">
              <p className="text-xl font-medium text-white">Merci pour votre inscription!</p>
              <p className="mt-2 text-white">Vous recevrez prochainement nos actualités par email.</p>
            </div>
          ) : (
            <Form {...form}>
              <form onSubmit={form.handleSubmit(onSubmit)} className="flex flex-col md:flex-row gap-4 max-w-md mx-auto">
                <FormField
                  control={form.control}
                  name="email"
                  render={({ field }) => (
                    <FormItem className="flex-grow">
                      <FormControl>
                        <Input
                          placeholder="Votre adresse email"
                          {...field}
                          className="py-3 px-4 rounded-lg focus:outline-none focus:ring-2 focus:ring-white text-gray-800 border-2 border-white/30"
                        />
                      </FormControl>
                      <FormMessage className="text-red-200 mt-1 font-medium drop-shadow-sm" />
                    </FormItem>
                  )}
                />
                <Button
                  type="submit"
                  className="bg-[#ff9633] hover:bg-[#f97316] py-3 px-6 rounded-lg font-medium transition whitespace-nowrap text-white shadow-md"
                  disabled={mutation.isPending}
                >
                  {mutation.isPending ? "En cours..." : "S'abonner"}
                </Button>
              </form>
            </Form>
          )}
          
          <p className="mt-4 text-sm text-white/90 drop-shadow-sm">
            En vous inscrivant, vous acceptez notre politique de confidentialité. Désabonnement facile à tout moment.
          </p>
        </div>
      </div>
    </section>
  );
};

export default Newsletter;
