import { useState } from "react";
import { Link, useLocation } from "wouter";
import { 
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuTrigger
} from "@/components/ui/dropdown-menu";
import { Button } from "@/components/ui/button";
import { useQuery } from "@tanstack/react-query";
import { fetchCategories } from "@/lib/data";
import { ShoppingCart, ChevronDown, Search, Menu, X } from "lucide-react";

const Header = () => {
  const [location] = useLocation();
  const [mobileMenuOpen, setMobileMenuOpen] = useState(false);
  const [mobileCategoriesOpen, setMobileCategoriesOpen] = useState(false);

  const { data: categories = [] } = useQuery({
    queryKey: ['/api/categories'],
    staleTime: 1000 * 60 * 5, // 5 minutes
  });

  const toggleMobileMenu = () => {
    setMobileMenuOpen(!mobileMenuOpen);
  };

  const toggleMobileCategories = () => {
    setMobileCategoriesOpen(!mobileCategoriesOpen);
  };

  return (
    <header className="bg-white shadow-sm">
      <div className="container mx-auto px-4 py-4">
        <div className="flex flex-col lg:flex-row justify-between items-center">
          <div className="flex items-center mb-4 lg:mb-0">
            <Link href="/">
              <a className="font-bold text-2xl">
                <span className="text-[#F59E0B]">Karukera</span>
                <span className="text-primary">Biz</span>
              </a>
            </Link>
          </div>
          
          <div className="w-full lg:w-auto">
            <div className="hidden lg:flex items-center space-x-8">
              <Link href="/">
                <a className={`font-medium hover:text-primary transition-colors duration-200 ${location === '/' ? 'text-primary' : ''}`}>
                  Accueil
                </a>
              </Link>
              
              <DropdownMenu>
                <DropdownMenuTrigger asChild>
                  <button className="flex items-center font-medium hover:text-primary transition-colors duration-200">
                    Catégories <ChevronDown className="ml-1 h-4 w-4" />
                  </button>
                </DropdownMenuTrigger>
                <DropdownMenuContent align="start" className="w-48">
                  {categories.map((category) => (
                    <DropdownMenuItem key={category.id} asChild>
                      <Link href={`/category/${category.name}`}>
                        <a className="block w-full cursor-pointer">{category.name}</a>
                      </Link>
                    </DropdownMenuItem>
                  ))}
                </DropdownMenuContent>
              </DropdownMenu>
              
              <Link href="/affiliates">
                <a className={`font-medium hover:text-primary transition-colors duration-200 ${location === '/affiliates' ? 'text-primary' : ''}`}>
                  Produits Affiliés
                </a>
              </Link>
              
              <Link href="/contact">
                <a className={`font-medium hover:text-primary transition-colors duration-200 ${location === '/contact' ? 'text-primary' : ''}`}>
                  Contact
                </a>
              </Link>
            </div>
            
            {/* Mobile menu button */}
            <div className="lg:hidden flex justify-between items-center">
              <button 
                onClick={toggleMobileMenu} 
                className="text-gray-500 hover:text-gray-600 focus:outline-none"
              >
                {mobileMenuOpen ? (
                  <X className="h-6 w-6" />
                ) : (
                  <Menu className="h-6 w-6" />
                )}
              </button>
            </div>
          </div>
          
          <div className="hidden lg:flex items-center space-x-4">
            <button className="text-primary hover:text-primary/90">
              <Search className="h-5 w-5" />
            </button>
            <button className="relative text-primary hover:text-primary/90">
              <ShoppingCart className="h-5 w-5" />
              <span className="absolute -top-2 -right-2 bg-[#F59E0B] text-white text-xs w-5 h-5 rounded-full flex items-center justify-center">
                3
              </span>
            </button>
            <Button className="bg-primary text-white hover:bg-primary/90 transition-colors duration-200">
              Se connecter
            </Button>
          </div>
        </div>
        
        {/* Mobile menu */}
        {mobileMenuOpen && (
          <div className="lg:hidden mt-4 pb-2">
            <div className="flex flex-col space-y-3">
              <Link href="/">
                <a className="font-medium">Accueil</a>
              </Link>
              
              <button 
                onClick={toggleMobileCategories}
                className="flex justify-between items-center font-medium"
              >
                Catégories <ChevronDown className={`ml-1 h-4 w-4 transition-transform ${mobileCategoriesOpen ? 'rotate-180' : ''}`} />
              </button>
              
              {mobileCategoriesOpen && (
                <div className="pl-4 py-2 space-y-2">
                  {categories.map((category) => (
                    <Link key={category.id} href={`/category/${category.name}`}>
                      <a className="block text-gray-700">{category.name}</a>
                    </Link>
                  ))}
                </div>
              )}
              
              <Link href="/affiliates">
                <a className="font-medium">Produits Affiliés</a>
              </Link>
              
              <Link href="/contact">
                <a className="font-medium">Contact</a>
              </Link>
              
              <div className="pt-2 flex space-x-4 border-t border-gray-200">
                <Button className="bg-primary text-white w-full">
                  Se connecter
                </Button>
              </div>
            </div>
          </div>
        )}
      </div>
    </header>
  );
};

export default Header;
