import { useState } from "react";
import { Link, useLocation } from "wouter";
import { Menu, Search, ShoppingCart } from "@/lib/icons";
import { cn } from "@/lib/utils";
import { useCart } from "@/hooks/use-cart";

const Navbar = () => {
  const [isMobileMenuOpen, setIsMobileMenuOpen] = useState(false);
  const [, setLocation] = useLocation();
  const { totalItems } = useCart();

  const toggleMobileMenu = () => {
    setIsMobileMenuOpen(!isMobileMenuOpen);
  };

  // Fonction améliorée pour gérer les liens avec ancres
  const handleNavLinkClick = (path: string) => {
    setIsMobileMenuOpen(false);
    
    // Si c'est un lien avec ancre sur la page d'accueil
    if (path.startsWith('/#')) {
      const id = path.split('#')[1];
      
      // Naviguer d'abord vers la page d'accueil si nous ne sommes pas déjà là
      if (window.location.pathname !== '/') {
        setLocation('/');
        // Attendre que la navigation se termine avant de faire défiler
        setTimeout(() => {
          const element = document.getElementById(id);
          if (element) {
            element.scrollIntoView({ behavior: 'smooth', block: 'start' });
          }
        }, 100);
      } else {
        // Nous sommes déjà sur la page d'accueil, faisons défiler directement
        const element = document.getElementById(id);
        if (element) {
          element.scrollIntoView({ behavior: 'smooth', block: 'start' });
        }
      }
    } else {
      // Pour les liens normaux, utilisez setLocation
      setLocation(path);
    }
  };

  return (
    <header className="bg-white shadow-sm sticky top-0 z-50">
      <div className="container mx-auto px-4 sm:px-6 lg:px-8">
        <div className="flex justify-between items-center py-4">
          <div className="flex items-center">
            <Link href="/" className="flex items-center">
              <span className="text-primary-700 text-2xl font-bold font-montserrat">
                Karukera<span className="text-teal-500">Biz</span>
              </span>
            </Link>
          </div>
          
          {/* Desktop Navigation */}
          <nav className="hidden md:flex space-x-8">
            <a 
              href="/" 
              className="text-gray-700 hover:text-primary-700 font-medium"
              onClick={(e) => {
                e.preventDefault();
                handleNavLinkClick("/");
              }}
            >
              Accueil
            </a>
            <a 
              href="/#categories" 
              className="text-gray-700 hover:text-primary-700 font-medium"
              onClick={(e) => {
                e.preventDefault();
                handleNavLinkClick("/#categories");
              }}
            >
              Catégories
            </a>
            <a 
              href="/#bestsellers" 
              className="text-gray-700 hover:text-primary-700 font-medium"
              onClick={(e) => {
                e.preventDefault();
                handleNavLinkClick("/#bestsellers");
              }}
            >
              Meilleures Ventes
            </a>
            <a 
              href="/affiliate" 
              className="text-gray-700 hover:text-primary-700 font-medium"
              onClick={(e) => {
                e.preventDefault();
                handleNavLinkClick("/affiliate");
              }}
            >
              Affiliation
            </a>
            <a 
              href="/#contact" 
              className="text-gray-700 hover:text-primary-700 font-medium"
              onClick={(e) => {
                e.preventDefault();
                handleNavLinkClick("/#contact");
              }}
            >
              Contact
            </a>
          </nav>
          
          <div className="flex items-center space-x-4">
            <button className="hidden md:inline-flex text-gray-700 hover:text-primary-700">
              <Search className="h-5 w-5" />
            </button>
            <button 
              className="text-gray-700 hover:text-primary-700 relative"
              onClick={() => handleNavLinkClick("/cart")}
            >
              <ShoppingCart className="h-5 w-5" />
              {totalItems > 0 && (
                <span className="absolute -top-2 -right-2 bg-[#ff9633] text-white text-xs rounded-full w-5 h-5 flex items-center justify-center">
                  {totalItems}
                </span>
              )}
            </button>
            <button 
              type="button" 
              className="md:hidden text-gray-700 hover:text-primary-700" 
              onClick={toggleMobileMenu}
            >
              <Menu className="h-5 w-5" />
            </button>
          </div>
        </div>
        
        {/* Mobile Navigation */}
        <div className={cn("md:hidden", isMobileMenuOpen ? "block" : "hidden")}>
          <div className="px-2 pt-2 pb-4 space-y-1">
            <a 
              href="/" 
              className="block px-3 py-2 rounded-md text-base font-medium text-gray-700 hover:text-primary-700 hover:bg-gray-50"
              onClick={(e) => {
                e.preventDefault();
                handleNavLinkClick("/");
              }}
            >
              Accueil
            </a>
            <a 
              href="/#categories" 
              className="block px-3 py-2 rounded-md text-base font-medium text-gray-700 hover:text-primary-700 hover:bg-gray-50"
              onClick={(e) => {
                e.preventDefault();
                handleNavLinkClick("/#categories");
              }}
            >
              Catégories
            </a>
            <a 
              href="/#bestsellers" 
              className="block px-3 py-2 rounded-md text-base font-medium text-gray-700 hover:text-primary-700 hover:bg-gray-50"
              onClick={(e) => {
                e.preventDefault();
                handleNavLinkClick("/#bestsellers");
              }}
            >
              Meilleures Ventes
            </a>
            <a 
              href="/affiliate" 
              className="block px-3 py-2 rounded-md text-base font-medium text-gray-700 hover:text-primary-700 hover:bg-gray-50"
              onClick={(e) => {
                e.preventDefault();
                handleNavLinkClick("/affiliate");
              }}
            >
              Affiliation
            </a>
            <a 
              href="/#contact" 
              className="block px-3 py-2 rounded-md text-base font-medium text-gray-700 hover:text-primary-700 hover:bg-gray-50"
              onClick={(e) => {
                e.preventDefault();
                handleNavLinkClick("/#contact");
              }}
            >
              Contact
            </a>
            <a 
              href="/cart" 
              className="block px-3 py-2 rounded-md text-base font-medium text-gray-700 hover:text-primary-700 hover:bg-gray-50"
              onClick={(e) => {
                e.preventDefault();
                handleNavLinkClick("/cart");
              }}
            >
              Panier {totalItems > 0 && <span className="ml-1 px-2 py-0.5 bg-[#ff9633] text-white text-xs rounded-full">{totalItems}</span>}
            </a>
          </div>
        </div>
      </div>
    </header>
  );
};

export default Navbar;
