import { useEffect } from "react";
import { useParams } from "wouter";
import { useQuery } from "@tanstack/react-query";
import { Button } from "@/components/ui/button";
import { Card, CardContent } from "@/components/ui/card";
import { Skeleton } from "@/components/ui/skeleton";
import { fetchProductsByCategory } from "@/lib/data";
import { formatPrice, truncateText } from "@/lib/utils";

const Category = () => {
  const { name } = useParams<{ name: string }>();
  const decodedName = name ? decodeURIComponent(name) : "";
  
  const { data: products = [], isLoading, refetch } = useQuery({
    queryKey: ['/api/products/category', decodedName],
    queryFn: () => fetchProductsByCategory(decodedName),
    enabled: !!decodedName,
  });

  useEffect(() => {
    if (decodedName) {
      refetch();
    }
  }, [decodedName, refetch]);

  return (
    <div className="py-12 bg-gray-50">
      <div className="container mx-auto px-4">
        <div className="mb-8">
          <h1 className="text-3xl font-bold mb-4">{decodedName}</h1>
          <p className="text-gray-600">
            {products.length} eBooks disponibles dans cette catégorie
          </p>
        </div>
        
        <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-4 gap-6">
          {isLoading ? (
            Array(8).fill(0).map((_, i) => (
              <Card key={i} className="overflow-hidden">
                <div className="relative pb-[140%]">
                  <Skeleton className="absolute inset-0" />
                </div>
                <CardContent className="p-4">
                  <Skeleton className="h-4 w-16 mb-1" />
                  <Skeleton className="h-6 w-full mb-2" />
                  <Skeleton className="h-4 w-full mb-3" />
                  <div className="flex justify-between items-center">
                    <Skeleton className="h-6 w-20" />
                    <Skeleton className="h-9 w-20" />
                  </div>
                </CardContent>
              </Card>
            ))
          ) : products.length > 0 ? (
            products.map((product) => (
              <Card key={product.id} className="bg-white rounded-lg shadow-md overflow-hidden hover:shadow-lg transition-shadow duration-300">
                <div className="relative pb-[140%]">
                  <img 
                    src={product.imageUrl}
                    alt={product.title}
                    className="absolute top-0 left-0 w-full h-full object-cover"
                  />
                  {product.isBestseller && (
                    <div className="absolute top-0 right-0 bg-[#F59E0B] text-white text-xs px-2 py-1 m-2 rounded">
                      Bestseller
                    </div>
                  )}
                  {product.isNew && (
                    <div className="absolute top-0 right-0 bg-[#C026D3] text-white text-xs px-2 py-1 m-2 rounded">
                      Nouveau
                    </div>
                  )}
                </div>
                <CardContent className="p-4">
                  <div className="text-xs text-gray-500 mb-1">{product.category}</div>
                  <h3 className="font-semibold text-lg mb-2">{product.title}</h3>
                  <p className="text-gray-600 text-sm mb-3 line-clamp-2">
                    {truncateText(product.description, 80)}
                  </p>
                  <div className="flex justify-between items-center">
                    <span className="font-bold text-lg text-primary">
                      {formatPrice(product.price)}
                    </span>
                    <Button className="bg-primary text-white hover:bg-primary/90 transition-colors duration-200">
                      Ajouter
                    </Button>
                  </div>
                </CardContent>
              </Card>
            ))
          ) : (
            <div className="col-span-full text-center py-12">
              <h3 className="text-xl font-semibold mb-2">
                Aucun eBook trouvé dans cette catégorie
              </h3>
              <p className="text-gray-600 mb-6">
                Consultez nos autres catégories ou revenez plus tard.
              </p>
              <Button className="bg-primary text-white hover:bg-primary/90" asChild>
                <a href="/">Retour à l'accueil</a>
              </Button>
            </div>
          )}
        </div>
      </div>
    </div>
  );
};

export default Category;
