import { useQuery } from "@tanstack/react-query";
import { useParams, Link } from "wouter";
import { Button } from "@/components/ui/button";
import { Skeleton } from "@/components/ui/skeleton";
import { Star, StarHalf, ChevronLeft } from "@/lib/icons";
import { type Category, type Product } from "@/lib/types";

const CategoryPage = () => {
  const { slug } = useParams();

  const { data: category, isLoading: categoryLoading } = useQuery<Category>({
    queryKey: [`/api/categories/${slug}`],
  });

  const { data: products, isLoading: productsLoading } = useQuery<Product[]>({
    queryKey: [`/api/categories/${slug}/products`],
  });

  const isLoading = categoryLoading || productsLoading;

  // Generate stars based on product rating
  const generateStars = (rating: number) => {
    const stars = [];
    const fullStars = Math.floor(rating);
    const hasHalfStar = rating - fullStars >= 0.5;
    
    for (let i = 0; i < fullStars; i++) {
      stars.push(<Star key={`star-${i}`} className="text-yellow-400" />);
    }
    
    if (hasHalfStar) {
      stars.push(<StarHalf key="half-star" className="text-yellow-400" />);
    }
    
    return stars;
  };

  return (
    <div className="bg-gray-50 py-12">
      <div className="container mx-auto px-4 sm:px-6 lg:px-8">
        <div className="mb-8">
          <Link href="/#categories" className="inline-flex items-center text-primary-600 hover:text-primary-700 mb-4">
            <ChevronLeft className="h-5 w-5 mr-1" /> Retour aux catégories
          </Link>
          
          {categoryLoading ? (
            <div className="space-y-3">
              <Skeleton className="h-10 w-2/3" />
              <Skeleton className="h-6 w-full max-w-2xl" />
            </div>
          ) : (
            <>
              <h1 className="text-3xl md:text-4xl font-bold font-montserrat text-gray-900 mb-2">
                {category?.name}
              </h1>
              <p className="text-lg text-gray-600">{category?.description}</p>
            </>
          )}
        </div>

        {isLoading ? (
          <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4 gap-6">
            {[...Array(4)].map((_, index) => (
              <div key={index} className="bg-white rounded-xl shadow-md overflow-hidden">
                <Skeleton className="h-56 w-full" />
                <div className="p-5">
                  <Skeleton className="h-6 w-3/4 mb-2" />
                  <Skeleton className="h-4 w-full mb-3" />
                  <div className="flex justify-between items-center mb-4">
                    <Skeleton className="h-5 w-16" />
                    <Skeleton className="h-4 w-24" />
                  </div>
                  <Skeleton className="h-10 w-full" />
                </div>
              </div>
            ))}
          </div>
        ) : products && products.length > 0 ? (
          <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4 gap-6">
            {products.map((product) => (
              <div key={product.id} className="bg-white rounded-xl shadow-md overflow-hidden hover:shadow-lg transition-shadow">
                <Link href={`/products/${product.slug}`}>
                  <div className="relative">
                    <img 
                      src={product.imageUrl} 
                      alt={product.title} 
                      className="w-full h-56 object-cover" 
                    />
                    {product.isBestseller && (
                      <div className="absolute top-3 right-3 bg-[#f97316] text-white text-sm font-medium py-1 px-2 rounded">
                        Bestseller
                      </div>
                    )}
                    {product.isNew && !product.isBestseller && (
                      <div className="absolute top-3 right-3 bg-[#f97316] text-white text-sm font-medium py-1 px-2 rounded">
                        Nouveauté
                      </div>
                    )}
                  </div>
                </Link>
                <div className="p-5">
                  <Link href={`/products/${product.slug}`}>
                    <h3 className="text-lg font-bold font-montserrat text-gray-900 mb-2 hover:text-primary-700">
                      {product.title}
                    </h3>
                  </Link>
                  <p className="text-gray-600 text-sm mb-3">{product.description}</p>
                  <div className="flex justify-between items-center mb-4">
                    <span className="text-[#f97316] font-bold">{product.price.toFixed(2)} €</span>
                    <div className="flex items-center">
                      {generateStars(product.rating)}
                      <span className="text-sm text-gray-500 ml-1">({product.reviewCount})</span>
                    </div>
                  </div>
                  <Button className="w-full bg-primary-700 hover:bg-primary-800 text-white font-medium">
                    Ajouter au panier
                  </Button>
                </div>
              </div>
            ))}
          </div>
        ) : (
          <div className="text-center py-12 bg-white rounded-lg shadow-sm">
            <h3 className="text-xl font-medium text-gray-700 mb-2">Aucun produit trouvé</h3>
            <p className="text-gray-600 mb-6">Il n'y a pas encore de produits dans cette catégorie.</p>
            <Button asChild variant="outline">
              <Link href="/#categories">Explorer d'autres catégories</Link>
            </Button>
          </div>
        )}
      </div>
    </div>
  );
};

export default CategoryPage;
