import { useEffect, useState } from "react";
import { useLocation } from "wouter";
import { useCart } from "@/hooks/use-cart";
import { Button } from "@/components/ui/button";
import { loadStripe } from "@stripe/stripe-js";
import {
  Elements,
  PaymentElement,
  useStripe,
  useElements,
} from "@stripe/react-stripe-js";
import { apiRequest } from "@/lib/queryClient";

const stripePromise = loadStripe(import.meta.env.VITE_STRIPE_PUBLIC_KEY);

const CheckoutForm = () => {
  const stripe = useStripe();
  const elements = useElements();
  const [error, setError] = useState<string | null>(null);
  const [processing, setProcessing] = useState(false);
  const [, setLocation] = useLocation();
  const { clearCart } = useCart();

  const handleSubmit = async (event: React.FormEvent) => {
    event.preventDefault();

    if (!stripe || !elements) {
      return;
    }

    setProcessing(true);

    const { error: submitError } = await stripe.confirmPayment({
      elements,
      confirmParams: {
        return_url: window.location.origin + "/confirmation",
      },
    });

    if (submitError) {
      setError(submitError.message || "Une erreur est survenue lors du paiement.");
      setProcessing(false);
    } else {
      clearCart();
      setLocation("/confirmation");
    }
  };

  return (
    <form onSubmit={handleSubmit} className="space-y-6">
      <PaymentElement />
      {error && (
        <div className="text-red-500 text-sm">{error}</div>
      )}
      <Button
        type="submit"
        disabled={!stripe || processing}
        className="w-full bg-[#ff9633] hover:bg-[#f97316] text-white font-medium"
      >
        {processing ? "Traitement en cours..." : "Payer maintenant"}
      </Button>
    </form>
  );
};

const CheckoutPage = () => {
  const [clientSecret, setClientSecret] = useState("");
  const { items, totalPrice } = useCart();
  const [, setLocation] = useLocation();

  useEffect(() => {
    if (items.length === 0) {
      setLocation("/cart");
      return;
    }

    const createPaymentIntent = async () => {
      try {
        const response = await apiRequest("POST", "/api/create-payment-intent", {
          amount: totalPrice * 100,
          items: items.map(item => ({
            id: item.product.id,
            quantity: item.quantity
          }))
        });
        const data = await response.json();
        setClientSecret(data.clientSecret);
      } catch (err) {
        console.error("Error creating payment intent:", err);
      }
    };

    createPaymentIntent();
  }, [items, totalPrice, setLocation]);

  if (items.length === 0) {
    return null;
  }

  return (
    <div className="container mx-auto px-4 py-16">
      <div className="max-w-2xl mx-auto">
        <h1 className="text-3xl font-bold mb-8">Paiement sécurisé</h1>
        
        <div className="bg-white rounded-lg shadow-lg p-6 mb-8">
          <h2 className="text-xl font-bold mb-4">Récapitulatif de la commande</h2>
          <div className="space-y-4">
            {items.map((item) => (
              <div key={item.product.id} className="flex justify-between items-center border-b pb-4">
                <div className="flex items-center">
                  <img
                    src={item.product.imageUrl}
                    alt={item.product.title}
                    className="w-16 h-20 object-cover rounded mr-4"
                  />
                  <div>
                    <h3 className="font-semibold">{item.product.title}</h3>
                    <p className="text-sm text-gray-600">Quantité: {item.quantity}</p>
                  </div>
                </div>
                <span className="font-medium">
                  {(item.product.price * item.quantity).toFixed(2)} €
                </span>
              </div>
            ))}
            
            <div className="flex justify-between font-bold text-lg pt-4">
              <span>Total</span>
              <span>{(totalPrice * 1.2).toFixed(2)} €</span>
            </div>
          </div>
        </div>

        {clientSecret && (
          <div className="bg-white rounded-lg shadow-lg p-6">
            <Elements stripe={stripePromise} options={{ clientSecret }}>
              <CheckoutForm />
            </Elements>
          </div>
        )}
      </div>
    </div>
  );
};

export default CheckoutPage;