import { useQuery } from "@tanstack/react-query";
import { useParams, Link } from "wouter";
import { Button } from "@/components/ui/button";
import { Skeleton } from "@/components/ui/skeleton";
import { ChevronLeft, Star, StarHalf } from "@/lib/icons";
import { type Product, type Category } from "@/lib/types";

const ProductPage = () => {
  const { slug } = useParams();

  const { data: product, isLoading: productLoading } = useQuery<Product>({
    queryKey: [`/api/products/${slug}`],
  });

  const { data: category, isLoading: categoryLoading } = useQuery<Category>({
    queryKey: [`/api/categories/${product?.categoryId}`],
    enabled: !!product?.categoryId,
  });

  const isLoading = productLoading || (product && categoryLoading);

  // Generate stars based on product rating
  const generateStars = (rating: number) => {
    const stars = [];
    const fullStars = Math.floor(rating);
    const hasHalfStar = rating - fullStars >= 0.5;
    
    for (let i = 0; i < fullStars; i++) {
      stars.push(<Star key={`star-${i}`} className="text-yellow-400" />);
    }
    
    if (hasHalfStar) {
      stars.push(<StarHalf key="half-star" className="text-yellow-400" />);
    }
    
    return stars;
  };

  if (!product && !isLoading) {
    return (
      <div className="bg-gray-50 py-24">
        <div className="container mx-auto px-4 sm:px-6 lg:px-8 text-center">
          <h1 className="text-2xl font-bold mb-4">Produit non trouvé</h1>
          <p className="mb-6">Le produit que vous recherchez n'existe pas ou a été supprimé.</p>
          <Button asChild>
            <Link href="/">Retourner à l'accueil</Link>
          </Button>
        </div>
      </div>
    );
  }

  return (
    <div className="bg-gray-50 py-12">
      <div className="container mx-auto px-4 sm:px-6 lg:px-8">
        <div className="mb-8">
          {category ? (
            <Link 
              href={`/categories/${category.slug}`} 
              className="inline-flex items-center text-primary-600 hover:text-primary-700"
            >
              <ChevronLeft className="h-5 w-5 mr-1" /> Retour à {category.name}
            </Link>
          ) : (
            <Link 
              href="/" 
              className="inline-flex items-center text-primary-600 hover:text-primary-700"
            >
              <ChevronLeft className="h-5 w-5 mr-1" /> Retour à l'accueil
            </Link>
          )}
        </div>

        {isLoading ? (
          <div className="bg-white rounded-xl shadow-md overflow-hidden">
            <div className="grid md:grid-cols-2 gap-8">
              <Skeleton className="h-96 md:h-full w-full" />
              <div className="p-8 space-y-6">
                <div className="space-y-2">
                  <Skeleton className="h-8 w-3/4" />
                  <Skeleton className="h-4 w-1/3" />
                </div>
                <Skeleton className="h-6 w-1/4" />
                <div className="space-y-2">
                  <Skeleton className="h-4 w-full" />
                  <Skeleton className="h-4 w-full" />
                  <Skeleton className="h-4 w-3/4" />
                </div>
                <div className="pt-4">
                  <Skeleton className="h-12 w-full" />
                </div>
              </div>
            </div>
          </div>
        ) : product && (
          <div className="bg-white rounded-xl shadow-md overflow-hidden">
            <div className="grid md:grid-cols-2 gap-8">
              <div className="relative p-8 flex items-center justify-center bg-gray-100">
                <img 
                  src={product.imageUrl} 
                  alt={product.title} 
                  className="max-h-96 object-contain shadow-lg rounded-lg" 
                />
                {product.isBestseller && (
                  <div className="absolute top-6 right-6 bg-[#ea580c] text-white font-medium py-1 px-3 rounded-md shadow-sm">
                    Bestseller
                  </div>
                )}
                {product.isNew && !product.isBestseller && (
                  <div className="absolute top-6 right-6 bg-[#ea580c] text-white font-medium py-1 px-3 rounded-md shadow-sm">
                    Nouveauté
                  </div>
                )}
              </div>
              <div className="p-8 flex flex-col">
                <div className="mb-4">
                  <h1 className="text-3xl font-bold font-montserrat text-gray-900 mb-2">
                    {product.title}
                  </h1>
                  {category && (
                    <Link 
                      href={`/categories/${category.slug}`}
                      className="text-primary-600 hover:text-primary-700"
                    >
                      {category.name}
                    </Link>
                  )}
                </div>
                
                <div className="flex items-center mb-6">
                  <div className="flex mr-2">
                    {generateStars(product.rating)}
                  </div>
                  <span className="text-sm text-gray-500">({product.reviewCount} avis)</span>
                </div>
                
                <div className="text-2xl font-bold text-[#f97316] mb-6">
                  {product.price.toFixed(2)} €
                </div>
                
                <div className="mb-8">
                  <h3 className="text-lg font-semibold mb-2">Description</h3>
                  <p className="text-gray-700">{product.description}</p>
                </div>
                
                <div className="mt-auto">
                  <Button className="w-full bg-primary-700 hover:bg-primary-800 text-white font-medium py-3">
                    Ajouter au panier
                  </Button>
                </div>
              </div>
            </div>
          </div>
        )}
      </div>
    </div>
  );
};

export default ProductPage;
