import { 
  users, categories, products, affiliateProducts, contacts, newsletters, 
  type User, type Category, type Product, type AffiliateProduct, type Contact, type Newsletter,
  type InsertUser, type InsertCategory, type InsertProduct, type InsertAffiliateProduct, 
  type InsertContact, type InsertNewsletter
} from "@shared/schema";

export interface IStorage {
  // User methods
  getUser(id: number): Promise<User | undefined>;
  getUserByUsername(username: string): Promise<User | undefined>;
  createUser(user: InsertUser): Promise<User>;
  
  // Category methods
  getAllCategories(): Promise<Category[]>;
  getCategoryById(id: number): Promise<Category | undefined>;
  getCategoryBySlug(slug: string): Promise<Category | undefined>;
  createCategory(category: InsertCategory): Promise<Category>;
  
  // Product methods
  getAllProducts(): Promise<Product[]>;
  getProductById(id: number): Promise<Product | undefined>;
  getProductBySlug(slug: string): Promise<Product | undefined>;
  getProductsByCategory(categoryId: number): Promise<Product[]>;
  getProductsByCategorySlug(categorySlug: string): Promise<Product[]>;
  getBestsellerProducts(limit?: number): Promise<Product[]>;
  getNewProducts(limit?: number): Promise<Product[]>;
  createProduct(product: InsertProduct): Promise<Product>;
  
  // Affiliate products methods
  getAllAffiliateProducts(): Promise<AffiliateProduct[]>;
  getAffiliateProductById(id: number): Promise<AffiliateProduct | undefined>;
  createAffiliateProduct(product: InsertAffiliateProduct): Promise<AffiliateProduct>;
  
  // Contact methods
  createContact(contact: InsertContact): Promise<Contact>;
  
  // Newsletter methods
  subscribeToNewsletter(newsletter: InsertNewsletter): Promise<Newsletter>;
}

export class MemStorage implements IStorage {
  private users: Map<number, User>;
  private categories: Map<number, Category>;
  private products: Map<number, Product>;
  private affiliateProducts: Map<number, AffiliateProduct>;
  private contacts: Map<number, Contact>;
  private newsletters: Map<number, Newsletter>;
  
  private userId: number;
  private categoryId: number;
  private productId: number;
  private affiliateProductId: number;
  private contactId: number;
  private newsletterId: number;
  
  constructor() {
    this.users = new Map();
    this.categories = new Map();
    this.products = new Map();
    this.affiliateProducts = new Map();
    this.contacts = new Map();
    this.newsletters = new Map();
    
    this.userId = 1;
    this.categoryId = 1;
    this.productId = 1;
    this.affiliateProductId = 1;
    this.contactId = 1;
    this.newsletterId = 1;
    
    // Initialize with sample data
    this.initializeData();
  }
  
  private initializeData() {
    // Create categories
    const businessCategory = this.createCategory({
      name: "Business",
      slug: "business",
      description: "Stratégies, leadership et croissance pour entrepreneurs",
      colorClass: "bg-primary-800",
      imageUrl: "https://images.unsplash.com/photo-1507679799987-c73779587ccf?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&q=80"
    });
    
    const romanceCategory = this.createCategory({
      name: "Romans",
      slug: "romans",
      description: "Histoires captivantes d'amour, d'aventure et de mystère",
      colorClass: "bg-teal-600",
      imageUrl: "https://images.unsplash.com/photo-1506880018603-83d5b814b5a6?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&q=80"
    });
    
    const guidesCategory = this.createCategory({
      name: "Guides Pratiques",
      slug: "guides",
      description: "Conseils et astuces pour améliorer votre quotidien",
      colorClass: "bg-coral-500",
      imageUrl: "https://images.unsplash.com/photo-1434030216411-0b793f4b4173?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&q=80"
    });
    
    const devPersoCategory = this.createCategory({
      name: "Développement Personnel",
      slug: "developpement-personnel",
      description: "Transformez votre vie et atteignez votre plein potentiel",
      colorClass: "bg-primary-600",
      imageUrl: "https://images.unsplash.com/photo-1499750310107-5fef28a66643?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&q=80"
    });
    
    // Create products
    this.createProduct({
      title: "Stratégies de Succès pour Entrepreneurs",
      slug: "strategies-succes-entrepreneurs",
      description: "Guide complet pour développer votre business et atteindre vos objectifs",
      price: 19.99,
      categoryId: businessCategory.id,
      imageUrl: "https://images.unsplash.com/photo-1589829085413-56de8ae18c73?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&q=80",
      isBestseller: true,
      isNew: false
    });
    
    this.createProduct({
      title: "L'Art de la Négociation",
      slug: "art-negociation",
      description: "Techniques avancées pour négocier avec succès dans toutes les situations",
      price: 15.99,
      categoryId: businessCategory.id,
      imageUrl: "https://images.unsplash.com/photo-1532012197267-da84d127e765?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&q=80",
      isBestseller: false,
      isNew: false
    });
    
    this.createProduct({
      title: "Destinées Entrelacées",
      slug: "destinees-entrelacees",
      description: "Roman captivant où deux âmes se retrouvent à travers le temps",
      price: 12.99,
      categoryId: romanceCategory.id,
      imageUrl: "https://images.unsplash.com/photo-1516383607781-913a19294fd1?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&q=80",
      isBestseller: false,
      isNew: true
    });
    
    this.createProduct({
      title: "Guide Nutrition Complète",
      slug: "guide-nutrition-complete",
      description: "Tout ce que vous devez savoir pour une alimentation équilibrée",
      price: 17.99,
      categoryId: guidesCategory.id,
      imageUrl: "https://images.unsplash.com/photo-1514416309827-bfb0cf433a2d?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&q=80",
      isBestseller: true,
      isNew: false
    });
    
    this.createProduct({
      title: "Méditation pour Débutants",
      slug: "meditation-debutants",
      description: "Apprenez à méditer en 30 jours et transformez votre quotidien",
      price: 14.99,
      categoryId: devPersoCategory.id,
      imageUrl: "https://images.unsplash.com/photo-1470290378698-263af93e2332?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&q=80",
      isBestseller: true,
      isNew: true
    });
    
    // Create affiliate products
    this.createAffiliateProduct({
      title: "Casque Audio Premium",
      description: "Le compagnon parfait pour vos audiobooks",
      price: 89.99,
      storeUrl: "https://www.amazon.fr/casque-audio-premium",
      storeName: "Amazon Store",
      imageUrl: "https://images.unsplash.com/photo-1505740420928-5e560c06d30e?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&q=80"
    });
    
    this.createAffiliateProduct({
      title: "Liseuse Électronique",
      description: "Profitez de vos eBooks avec un confort optimal",
      price: 129.99,
      storeUrl: "https://www.amazon.fr/kindle-paperwhite",
      storeName: "Kindle Shop",
      imageUrl: "https://images.unsplash.com/photo-1542751371-adc38448a05e?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&q=80"
    });
    
    this.createAffiliateProduct({
      title: "Formation Business en Ligne",
      description: "Approfondissez vos connaissances entrepreneuriales",
      price: 199.99,
      storeUrl: "https://www.udemy.com/course/business-formation",
      storeName: "Udemy",
      imageUrl: "https://images.unsplash.com/photo-1534531173927-aeb928d54385?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&q=80"
    });
  }
  
  // User methods
  async getUser(id: number): Promise<User | undefined> {
    return this.users.get(id);
  }
  
  async getUserByUsername(username: string): Promise<User | undefined> {
    return Array.from(this.users.values()).find(
      (user) => user.username === username,
    );
  }
  
  async createUser(insertUser: InsertUser): Promise<User> {
    const id = this.userId++;
    const now = new Date().toISOString();
    const user: User = { ...insertUser, id, createdAt: now };
    this.users.set(id, user);
    return user;
  }
  
  // Category methods
  async getAllCategories(): Promise<Category[]> {
    return Array.from(this.categories.values());
  }
  
  async getCategoryById(id: number): Promise<Category | undefined> {
    return this.categories.get(id);
  }
  
  async getCategoryBySlug(slug: string): Promise<Category | undefined> {
    return Array.from(this.categories.values()).find(
      (category) => category.slug === slug,
    );
  }
  
  async createCategory(insertCategory: InsertCategory): Promise<Category> {
    const id = this.categoryId++;
    const category: Category = { ...insertCategory, id };
    this.categories.set(id, category);
    return category;
  }
  
  // Product methods
  async getAllProducts(): Promise<Product[]> {
    return Array.from(this.products.values());
  }
  
  async getProductById(id: number): Promise<Product | undefined> {
    return this.products.get(id);
  }
  
  async getProductBySlug(slug: string): Promise<Product | undefined> {
    return Array.from(this.products.values()).find(
      (product) => product.slug === slug,
    );
  }
  
  async getProductsByCategory(categoryId: number): Promise<Product[]> {
    return Array.from(this.products.values()).filter(
      (product) => product.categoryId === categoryId,
    );
  }
  
  async getProductsByCategorySlug(categorySlug: string): Promise<Product[]> {
    const category = await this.getCategoryBySlug(categorySlug);
    if (!category) return [];
    
    return this.getProductsByCategory(category.id);
  }
  
  async getBestsellerProducts(limit?: number): Promise<Product[]> {
    const bestsellers = Array.from(this.products.values()).filter(
      (product) => product.isBestseller,
    );
    
    return limit ? bestsellers.slice(0, limit) : bestsellers;
  }
  
  async getNewProducts(limit?: number): Promise<Product[]> {
    const newProducts = Array.from(this.products.values()).filter(
      (product) => product.isNew,
    );
    
    return limit ? newProducts.slice(0, limit) : newProducts;
  }
  
  async createProduct(insertProduct: InsertProduct): Promise<Product> {
    const id = this.productId++;
    const now = new Date().toISOString();
    const product: Product = { 
      ...insertProduct, 
      id, 
      rating: 4.5, 
      reviewCount: Math.floor(Math.random() * 50) + 5,
      createdAt: now 
    };
    this.products.set(id, product);
    return product;
  }
  
  // Affiliate products methods
  async getAllAffiliateProducts(): Promise<AffiliateProduct[]> {
    return Array.from(this.affiliateProducts.values());
  }
  
  async getAffiliateProductById(id: number): Promise<AffiliateProduct | undefined> {
    return this.affiliateProducts.get(id);
  }
  
  async createAffiliateProduct(insertAffiliateProduct: InsertAffiliateProduct): Promise<AffiliateProduct> {
    const id = this.affiliateProductId++;
    const now = new Date().toISOString();
    const affiliateProduct: AffiliateProduct = { 
      ...insertAffiliateProduct, 
      id, 
      createdAt: now 
    };
    this.affiliateProducts.set(id, affiliateProduct);
    return affiliateProduct;
  }
  
  // Contact methods
  async createContact(insertContact: InsertContact): Promise<Contact> {
    const id = this.contactId++;
    const now = new Date().toISOString();
    const contact: Contact = { 
      ...insertContact, 
      id, 
      createdAt: now 
    };
    this.contacts.set(id, contact);
    return contact;
  }
  
  // Newsletter methods
  async subscribeToNewsletter(insertNewsletter: InsertNewsletter): Promise<Newsletter> {
    // Check if email already exists
    const existingSubscription = Array.from(this.newsletters.values()).find(
      (newsletter) => newsletter.email === insertNewsletter.email,
    );
    
    if (existingSubscription) {
      return existingSubscription;
    }
    
    const id = this.newsletterId++;
    const now = new Date().toISOString();
    const newsletter: Newsletter = { 
      ...insertNewsletter, 
      id, 
      createdAt: now 
    };
    this.newsletters.set(id, newsletter);
    return newsletter;
  }
}

export const storage = new MemStorage();
